@@ -297,6 +297,84 @@ if( $this->CheckPermission('Approve GCharts') )
 	  $timeline = $params['timeline'];
 	}
 
+	$allowHtml = '';
+	if (isset($params['allowHtml']))
+	{
+	  $allowHtml = $params['allowHtml'];
+	}
+
+	$alternatingRowStyle = '';
+	if (isset($params['alternatingRowStyle']))
+	{
+	  $alternatingRowStyle = $params['alternatingRowStyle'];
+	}
+
+	$cssClassNames = '';
+	if (isset($params['cssClassNames']))
+	{
+	  $cssClassNames = $params['cssClassNames'];
+	}
+
+	$firstRowNumber = '';
+	if (isset($params['firstRowNumber']))
+	{
+	  $firstRowNumber = $params['firstRowNumber'];
+	}
+
+	$chartpage = '';
+	if (isset($params['chartpage']))
+	{
+	  $chartpage = $params['chartpage'];
+	}
+
+	$pageSize = '';
+	if (isset($params['pageSize']))
+	{
+	  $pageSize = $params['pageSize'];
+	}
+
+	$rtlTable = '';
+	if (isset($params['rtlTable']))
+	{
+	  $rtlTable = $params['rtlTable'];
+	}
+
+	$scrollLeftStartPosition = '';
+	if (isset($params['scrollLeftStartPosition']))
+	{
+	  $scrollLeftStartPosition = $params['scrollLeftStartPosition'];
+	}
+
+	$showRowNumber = '';
+	if (isset($params['showRowNumber']))
+	{
+	  $showRowNumber = $params['showRowNumber'];
+	}
+
+	$sort = '';
+	if (isset($params['sort']))
+	{
+	  $sort = $params['sort'];
+	}
+
+	$sortAscending = '';
+	if (isset($params['sortAscending']))
+	{
+	  $sortAscending = $params['sortAscending'];
+	}
+
+	$sortColumn = '';
+	if (isset($params['sortColumn']))
+	{
+	  $sortColumn = $params['sortColumn'];
+	}
+
+	$startPage = '';
+	if (isset($params['startPage']))
+	{
+	  $startPage = $params['startPage'];
+	}
+
 if( isset($params['submit']) )
   {
     $error = FALSE;
@@ -319,8 +397,8 @@ if( isset($params['submit']) )
     else
       {
 	$chartid = $db->GenID(cms_db_prefix()."module_gcharts_seq");
-	$query = 'INSERT INTO '.cms_db_prefix().'module_gcharts (gcharts_id, gcharts_category_id, gcharts_element_id, gcharts_name, gcharts_data, axisTitlesPosition, backgroundColor, curveType, chartArea, colors, enableInteractivity, focusTarget, fontSize, fontName, hAxes, hAxis, height, interpolatedNulls, isHtml, isStacked, is3D, legend, lineWidth, slices, pieSliceBorderColor, pieSliceText, pieSliceTextStyle, pointSize, reverseCategories, series, sliceVisibilityThreshold, pieResidueSliceColor, pieResidueSliceLabel, theme, title, titlePosition, titleTextStyle, tooltip, vAxes, vAxis, width, status, aggregationTarget, groupWidth, dataOpacity, avoidOverlappingGridLines, timeline) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)';
-	$dbr = $db->Execute($query, array($chartid, $usedcategory, $element, $name, $data, $axisTitlesPosition, $backgroundColor, $curveType, $chartArea, $colors, $enableInteractivity, $focusTarget, $fontSize, $fontName, $hAxes, $hAxis, $height, $interpolatedNulls, $isStacked, $isHtml, $is3D, $legend, $lineWidth, $slices, $pieSliceBorderColor, $pieSliceText, $pieSliceTextStyle, $pointSize, $reverseCategories, $series, $sliceVisibilityThreshold, $pieResidueSliceColor, $pieResidueSliceLabel, $theme, $title, $titlePosition, $titleTextStyle, $tooltip, $vAxes, $vAxis, $width, $status, $aggregationTarget, $groupWidth, $dataOpacity, $avoidOverlappingGridLines, $timeline));
+	$query = 'INSERT INTO '.cms_db_prefix().'module_gcharts (gcharts_id, gcharts_category_id, gcharts_element_id, gcharts_name, gcharts_data, axisTitlesPosition, backgroundColor, curveType, chartArea, colors, enableInteractivity, focusTarget, fontSize, fontName, hAxes, hAxis, height, interpolatedNulls, isHtml, isStacked, is3D, legend, lineWidth, slices, pieSliceBorderColor, pieSliceText, pieSliceTextStyle, pointSize, reverseCategories, series, sliceVisibilityThreshold, pieResidueSliceColor, pieResidueSliceLabel, theme, title, titlePosition, titleTextStyle, tooltip, vAxes, vAxis, width, status, aggregationTarget, groupWidth, dataOpacity, avoidOverlappingGridLines, timeline, allowHtml, alternatingRowStyle, cssClassNames, firstRowNumber, chartpage, pageSize, rtlTable, scrollLeftStartPosition, showRowNumber, sort, sortAscending, sortColumn, startPage) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)';
+	$dbr = $db->Execute($query, array($chartid, $usedcategory, $element, $name, $data, $axisTitlesPosition, $backgroundColor, $curveType, $chartArea, $colors, $enableInteractivity, $focusTarget, $fontSize, $fontName, $hAxes, $hAxis, $height, $interpolatedNulls, $isStacked, $isHtml, $is3D, $legend, $lineWidth, $slices, $pieSliceBorderColor, $pieSliceText, $pieSliceTextStyle, $pointSize, $reverseCategories, $series, $sliceVisibilityThreshold, $pieResidueSliceColor, $pieResidueSliceLabel, $theme, $title, $titlePosition, $titleTextStyle, $tooltip, $vAxes, $vAxis, $width, $status, $aggregationTarget, $groupWidth, $dataOpacity, $avoidOverlappingGridLines, $timeline, $allowHtml, $alternatingRowStyle, $cssClassNames, $firstRowNumber, $chartpage, $pageSize, $rtlTable, $scrollLeftStartPosition, $showRowNumber, $sort, $sortAscending, $sortColumn, $startPage));
     
 	if( !$dbr )
 	  {
@@ -419,6 +497,19 @@ $smarty->assign('startform', $this->CreateFormStart($id, 'addchart', $returnid,'
 	$smarty->assign('inputdataOpacity', $this->CreateInputText($id, 'dataOpacity', $dataOpacity, 30, 255));
 	$smarty->assign('inputavoidOverlappingGridLines', $this->CreateInputText($id, 'avoidOverlappingGridLines', $avoidOverlappingGridLines, 30, 255));
 	$smarty->assign('inputtimeline', $this->CreateInputText($id, 'timeline', $timeline, 30, 255));
+	$smarty->assign('inputallowHtml', $this->CreateInputText($id, 'allowHtml', $allowHtml, 30, 255));
+	$smarty->assign('inputalternatingRowStyle', $this->CreateInputText($id, 'alternatingRowStyle', $alternatingRowStyle, 30, 255));
+	$smarty->assign('inputcssClassNames', $this->CreateInputText($id, 'cssClassNames', $cssClassNames, 30, 255));
+	$smarty->assign('inputfirstRowNumber', $this->CreateInputText($id, 'firstRowNumber', $firstRowNumber, 30, 255));
+	$smarty->assign('inputchartpage', $this->CreateInputText($id, 'chartpage', $chartpage, 30, 255));
+	$smarty->assign('inputpageSize', $this->CreateInputText($id, 'pageSize', $pageSize, 30, 255));
+	$smarty->assign('inputrtlTable', $this->CreateInputText($id, 'rtlTable', $rtlTable, 30, 255));
+	$smarty->assign('inputscrollLeftStartPosition', $this->CreateInputText($id, 'scrollLeftStartPosition', $scrollLeftStartPosition, 30, 255));
+	$smarty->assign('inputshowRowNumber', $this->CreateInputText($id, 'showRowNumber', $showRowNumber, 30, 255));
+	$smarty->assign('inputsort', $this->CreateInputText($id, 'sort', $sort, 30, 255));
+	$smarty->assign('inputsortAscending', $this->CreateInputText($id, 'sortAscending', $sortAscending, 30, 255));
+	$smarty->assign('inputsortColumn', $this->CreateInputText($id, 'sortColumn', $sortColumn, 30, 255));
+	$smarty->assign('inputstartPage', $this->CreateInputText($id, 'startPage', $startPage, 30, 255));
 $smarty->assign('actionid',$id);
 if( $this->CheckPermission('Approve GCharts') )
   {
@@ -437,47 +528,60 @@ $smarty->assign('inputcategory', $this->CreateInputDropdown($id, 'category', $ca
 	$smarty->assign('elementtext', $this->Lang('element'));
 	$smarty->assign('categorytext', $this->Lang('category'));
 	$smarty->assign('datatext', $this->Lang('data'));
-$smarty->assign('axisTitlesPositiontext', $this->Lang('axisTitlesPosition'));
-$smarty->assign('backgroundColortext', $this->Lang('backgroundColor'));
-$smarty->assign('chartAreatext', $this->Lang('chartArea'));
-$smarty->assign('colorstext', $this->Lang('colors'));
-$smarty->assign('curveTypetext', $this->Lang('curveType'));
-$smarty->assign('enableInteractivitytext', $this->Lang('enableInteractivity'));
-$smarty->assign('focusTargettext', $this->Lang('focusTarget'));
-$smarty->assign('fontSizetext', $this->Lang('fontSize'));
-$smarty->assign('fontNametext', $this->Lang('fontName'));
-$smarty->assign('hAxestext', $this->Lang('hAxes'));
-$smarty->assign('hAxistext', $this->Lang('hAxis'));
-$smarty->assign('heighttext', $this->Lang('height'));
-$smarty->assign('interpolatedNullstext', $this->Lang('interpolatedNulls'));
-$smarty->assign('isHtmltext', $this->Lang('isHtml'));
-$smarty->assign('isStackedtext', $this->Lang('isStacked'));
-$smarty->assign('is3Dtext', $this->Lang('is3D'));
-$smarty->assign('legendtext', $this->Lang('legend'));
-$smarty->assign('lineWidthtext', $this->Lang('lineWidth'));
-$smarty->assign('slicestext', $this->Lang('slices'));
-$smarty->assign('pieSliceBorderColortext', $this->Lang('pieSliceBorderColor'));
-$smarty->assign('pieSliceTexttext', $this->Lang('pieSliceText'));
-$smarty->assign('pieSliceTextStyletext', $this->Lang('pieSliceTextStyle'));
-$smarty->assign('pointSizetext', $this->Lang('pointSize'));
-$smarty->assign('reverseCategoriestext', $this->Lang('reverseCategories'));
-$smarty->assign('seriestext', $this->Lang('series'));
-$smarty->assign('sliceVisibilityThresholdtext', $this->Lang('sliceVisibilityThreshold'));
-$smarty->assign('pieResidueSliceColortext', $this->Lang('pieResidueSliceColor'));
-$smarty->assign('pieResidueSliceLabeltext', $this->Lang('pieResidueSliceLabel'));
-$smarty->assign('themetext', $this->Lang('theme'));
-$smarty->assign('titletext', $this->Lang('title'));
-$smarty->assign('titlePositiontext', $this->Lang('titlePosition'));
-$smarty->assign('titleTextStyletext', $this->Lang('titleTextStyle'));
-$smarty->assign('tooltiptext', $this->Lang('tooltip'));
-$smarty->assign('vAxestext', $this->Lang('vAxes'));
-$smarty->assign('vAxistext', $this->Lang('vAxis'));
-$smarty->assign('widthtext', $this->Lang('width'));
-$smarty->assign('aggregationTargettext', $this->Lang('aggregationTarget'));
-$smarty->assign('groupWidthtext', $this->Lang('groupWidth'));
-$smarty->assign('dataOpacitytext', $this->Lang('dataOpacity'));
-$smarty->assign('avoidOverlappingGridLinestext', $this->Lang('avoidOverlappingGridLines'));
-$smarty->assign('timelinetext', $this->Lang('timeline'));
+	$smarty->assign('axisTitlesPositiontext', $this->Lang('axisTitlesPosition'));
+	$smarty->assign('backgroundColortext', $this->Lang('backgroundColor'));
+	$smarty->assign('chartAreatext', $this->Lang('chartArea'));
+	$smarty->assign('colorstext', $this->Lang('colors'));
+	$smarty->assign('curveTypetext', $this->Lang('curveType'));
+	$smarty->assign('enableInteractivitytext', $this->Lang('enableInteractivity'));
+	$smarty->assign('focusTargettext', $this->Lang('focusTarget'));
+	$smarty->assign('fontSizetext', $this->Lang('fontSize'));
+	$smarty->assign('fontNametext', $this->Lang('fontName'));
+	$smarty->assign('hAxestext', $this->Lang('hAxes'));
+	$smarty->assign('hAxistext', $this->Lang('hAxis'));
+	$smarty->assign('heighttext', $this->Lang('height'));
+	$smarty->assign('interpolatedNullstext', $this->Lang('interpolatedNulls'));
+	$smarty->assign('isHtmltext', $this->Lang('isHtml'));
+	$smarty->assign('isStackedtext', $this->Lang('isStacked'));
+	$smarty->assign('is3Dtext', $this->Lang('is3D'));
+	$smarty->assign('legendtext', $this->Lang('legend'));
+	$smarty->assign('lineWidthtext', $this->Lang('lineWidth'));
+	$smarty->assign('slicestext', $this->Lang('slices'));
+	$smarty->assign('pieSliceBorderColortext', $this->Lang('pieSliceBorderColor'));
+	$smarty->assign('pieSliceTexttext', $this->Lang('pieSliceText'));
+	$smarty->assign('pieSliceTextStyletext', $this->Lang('pieSliceTextStyle'));
+	$smarty->assign('pointSizetext', $this->Lang('pointSize'));
+	$smarty->assign('reverseCategoriestext', $this->Lang('reverseCategories'));
+	$smarty->assign('seriestext', $this->Lang('series'));
+	$smarty->assign('sliceVisibilityThresholdtext', $this->Lang('sliceVisibilityThreshold'));
+	$smarty->assign('pieResidueSliceColortext', $this->Lang('pieResidueSliceColor'));
+	$smarty->assign('pieResidueSliceLabeltext', $this->Lang('pieResidueSliceLabel'));
+	$smarty->assign('themetext', $this->Lang('theme'));
+	$smarty->assign('titletext', $this->Lang('title'));
+	$smarty->assign('titlePositiontext', $this->Lang('titlePosition'));
+	$smarty->assign('titleTextStyletext', $this->Lang('titleTextStyle'));
+	$smarty->assign('tooltiptext', $this->Lang('tooltip'));
+	$smarty->assign('vAxestext', $this->Lang('vAxes'));
+	$smarty->assign('vAxistext', $this->Lang('vAxis'));
+	$smarty->assign('widthtext', $this->Lang('width'));
+	$smarty->assign('aggregationTargettext', $this->Lang('aggregationTarget'));
+	$smarty->assign('groupWidthtext', $this->Lang('groupWidth'));
+	$smarty->assign('dataOpacitytext', $this->Lang('dataOpacity'));
+	$smarty->assign('avoidOverlappingGridLinestext', $this->Lang('avoidOverlappingGridLines'));
+	$smarty->assign('timelinetext', $this->Lang('timeline'));
+	$smarty->assign('allowHtmltext', $this->Lang('allowHtml'));
+	$smarty->assign('alternatingRowStyletext', $this->Lang('alternatingRowStyle'));
+	$smarty->assign('cssClassNamestext', $this->Lang('cssClassNames'));
+	$smarty->assign('firstRowNumbertext', $this->Lang('firstRowNumber'));
+	$smarty->assign('chartpagetext', $this->Lang('chartpage'));
+	$smarty->assign('pageSizetext', $this->Lang('pageSize'));
+	$smarty->assign('rtlTabletext', $this->Lang('rtlTable'));
+	$smarty->assign('scrollLeftStartPositiontext', $this->Lang('scrollLeftStartPosition'));
+	$smarty->assign('showRowNumbertext', $this->Lang('showRowNumber'));
+	$smarty->assign('sorttext', $this->Lang('sort'));
+	$smarty->assign('sortAscendingtext', $this->Lang('sortAscending'));
+	$smarty->assign('sortColumntext', $this->Lang('sortColumn'));
+	$smarty->assign('startPagetext', $this->Lang('startPage'));
 
 // tab stuff.
 $smarty->assign('start_tab_headers',$this->StartTabHeaders());
